@@ -36,13 +36,17 @@ if (&is_module_available('CGI')) {
 } else {
   ok(1); print "\tskipped (ok 2) - CGI module not available\n"; }
 
-&testcase('02', 'replace');
-&testcase('03', 'replace');
-&testcase('05', 'replace');
-&testcase('06'); # was 5
-&testcase('07'); # was 25, Makefile
-&testcase('08'); # Makefile
-&testcase('09', 'replace'); # old 7, html
+if (&is_module_available('CGI')) {
+  &testcase('02', 'replace'); # "ok 3" requires CGI module
+} else {
+  ok(1); print "\tskipped (ok 3) - CGI module not available\n"; }
+
+&testcase('03', 'replace'); # "ok 4"
+&testcase('05', 'replace'); # "ok 5"
+&testcase('06'); # was 5 "ok 6"
+&testcase('07'); # was 25, Makefile "ok 7"
+&testcase('08'); # Makefile "ok 8"
+&testcase('09', 'replace'); # old 7, html "ok 9"
 &testcase(2);
 &testcase(3);
 &testcase(4);
